@@ -1351,7 +1351,11 @@ def main():
                 else:
                     user_name = aws_manager.get_default_ami_user_name(instance.image_id)
                 key_path = f"{aws_manager.home_folder}/{key_pair_name}.pem"
-                ssh_cmd = f"ssh {user_name}@{instance.public_ip_address} -i {key_path} {options.ssh_append}"
+                if options.ssh_append:
+                    append = options.ssh_append
+                else:
+                    append = ''
+                ssh_cmd = f"ssh {user_name}@{instance.public_ip_address} -i {key_path} {append}"
                 print(colored(f"Using the following command: {ssh_cmd}", 'green'))
                 os.system(ssh_cmd)
             else:
